@@ -122,7 +122,7 @@ class SharingCriteria (Model):
 
 
 class Entrepreneur(Model):
-    user = models.OneToOneField(settings.AUTH_USER_MODEL, related_name="entrepreneur_profile")
+    user = models.OneToOneField(settings.AUTH_USER_MODEL, related_name="entrepreneur_profile", on_delete=models.DO_NOTHING)
     organisation = models.ForeignKey(Organisation, null=True, on_delete=models.CASCADE, related_name="entrepreneurs")
     
     class Meta:
@@ -140,10 +140,10 @@ class Entrepreneur(Model):
         return self.user.get_full_name()
 
 class Mentor(Model):
-    user = models.OneToOneField(settings.AUTH_USER_MODEL, related_name="mentor_profile")
+    user = models.OneToOneField(settings.AUTH_USER_MODEL, related_name="mentor_profile", on_delete=models.DO_NOTHING)
     phone = models.CharField(max_length=25, null=True, blank=True, verbose_name='Phone number')
     organisation = models.ForeignKey(Organisation, null=True, on_delete=models.CASCADE, related_name="mentors")
-    country = models.ForeignKey(Country, null=True, related_name="mentors")
+    country = models.ForeignKey(Country, null=True, related_name="mentors", on_delete=models.DO_NOTHING)
     languages = models.ManyToManyField(Language, blank=True)
 
     headline = models.CharField(max_length=256, blank=True, null=True, verbose_name='Headline or current position')
@@ -198,11 +198,11 @@ class Resource (Model):
     # Mandatory Fields
     name = models.CharField(max_length=256, verbose_name="Title")
 
-    format = models.ForeignKey(Format, null=True, related_name='resources')
+    format = models.ForeignKey(Format, null=True, related_name='resources', on_delete=models.DO_NOTHING)
     publication_year = models.IntegerField(verbose_name="Publication Year", null=True, blank=True)
     languages = models.ManyToManyField(Language, blank=True, verbose_name="Languages", related_name='resources')
     fields = models.ManyToManyField(Field, blank=True, verbose_name="Fields", related_name='resources')
-    country = models.ForeignKey(Country, null=True)
+    country = models.ForeignKey(Country, null=True, on_delete=models.DO_NOTHING)
     uri = models.CharField(max_length=4086, verbose_name="Location/weblink")
     resource_author = models.CharField(max_length=256, verbose_name="Author")
     skills = models.ManyToManyField(LearningOutcome, blank=True, verbose_name="Learning outcomes/skills", related_name='resources')
@@ -213,9 +213,9 @@ class Resource (Model):
     preview_image = models.URLField(blank=True, null=True)
 
     # Classification Fields
-    target = models.ForeignKey(Target, verbose_name="Target audience", blank=True, null=True)
+    target = models.ForeignKey(Target, verbose_name="Target audience", blank=True, null=True, on_delete=models.DO_NOTHING)
     type = models.ManyToManyField(Type, blank=True, verbose_name="Type of content", related_name='resources')
-    sharing = models.ForeignKey(SharingCriteria, blank=True, null=True, verbose_name="Sharing profile", related_name='resources')
+    sharing = models.ForeignKey(SharingCriteria, blank=True, null=True, verbose_name="Sharing profile", related_name='resources', on_delete=models.DO_NOTHING)
 
     steps = models.ManyToManyField(Step, blank=True, related_name="resources")
 
@@ -224,7 +224,7 @@ class Resource (Model):
     related = models.ManyToManyField("self", blank=True)
     conversations = models.ManyToManyField(Conversation, blank=True, related_name='resources')
     likes = models.ManyToManyField(Like, blank=True, related_name='resources')
-    review = models.OneToOneField(Review, blank=True, null=True, verbose_name="Associated review", related_name='resource')
+    review = models.OneToOneField(Review, blank=True, null=True, verbose_name="Associated review", related_name='resource', on_delete=models.DO_NOTHING)
  
     class Meta:
         auto_author='submitter'
@@ -249,9 +249,9 @@ class Request (Model):
     description = models.TextField(verbose_name="Description")
     status = models.CharField(max_length=32, verbose_name="Status", choices=(('pending', 'Pending'), ('validated', 'Validated')), default="pending")
     
-    language = models.ForeignKey(Language, blank=True, verbose_name="Language")
+    language = models.ForeignKey(Language, blank=True, verbose_name="Language", on_delete=models.DO_NOTHING)
     fields = models.ManyToManyField(Field, blank=True)
-    country = models.ForeignKey(Country, null=True)
+    country = models.ForeignKey(Country, null=True, on_delete=models.DO_NOTHING)
 
     organisation = models.ForeignKey(Organisation, on_delete=models.CASCADE, related_name="requests")
     skills = models.TextField(verbose_name="Learning outcomes/skills")
@@ -278,7 +278,7 @@ class Request (Model):
         return self.name
 
 class BrokenLink(Model):
-    submitter = models.ForeignKey(settings.AUTH_USER_MODEL, related_name="brokenlink_submitter")
+    submitter = models.ForeignKey(settings.AUTH_USER_MODEL, on_delete=models.CASCADE, related_name="brokenlink_submitter")
     resource = models.ForeignKey(Resource, null=True, on_delete=models.CASCADE, related_name="brokenlink_resource")
     
     class Meta:
